==> components-1.1.0.tgz: package/es/Button/Button.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { defaultProps } from './props/defaultProps';
import { propTypes } from './props/propTypes';
import cssJSLogic from './css/cssJSLogic';
import { mergeStyle } from './../utils/';
import style from './css/Button.module.css';
/*
Button text and children props?
use children for both cases
toLowerCase check needed?
*/

/* eslint css-modules/no-unused-class: [2, { markAsUsed: ['small','medium','large','xlarge','button_medium','button_small','primary','primaryfilled','danger','dangerfilled','plainprimary', 'plainsecondary', 'secondary', 'secondaryfilled', 'successFilled','tertiaryFilled'] }] */

export default function Button(props) {
  let {
    text,
    disabled,
    onClick,
    status,
    children,
    dataId,
    needAppearance,
    getRef,
    title,
    dataSelectorId,
    customProps,
    customStyle
  } = props;
  const finalStyle = mergeStyle(style, customStyle);
  const {
    buttonClass,
    loaderParentClass,
    loaderChildClass
  } = cssJSLogic({
    props,
    style: finalStyle
  });
  let statusLower = status.toLowerCase();
  return /*#__PURE__*/React.createElement("button", _extends({
    className: buttonClass,
    "data-id": disabled ? `${dataId}_disabled` : dataId,
    "data-test-id": disabled ? `${dataId}_disabled` : dataId,
    disabled: disabled || statusLower === 'loading',
    onClick: onClick,
    "data-title": title,
    type: "button",
    ref: getRef,
    "data-selector-id": dataSelectorId
  }, customProps), children ? children : text, statusLower !== 'none' && needAppearance && /*#__PURE__*/React.createElement("div", {
    className: finalStyle.overlay
  }, /*#__PURE__*/React.createElement("div", {
    className: loaderParentClass
  }, /*#__PURE__*/React.createElement("div", {
    className: loaderChildClass
  }))));
}
Button.defaultProps = defaultProps;
Button.propTypes = propTypes; // if (__DOCS__) {
//   Button.docs = {
//     componentGroup: 'Form Elements',
//     folderName: 'Style Guide'
//   };
// }

==> components-1.2.0.tgz: package/es/Button/Button.js <==
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { defaultProps } from './props/defaultProps';
import { propTypes } from './props/propTypes';
import cssJSLogic from './css/cssJSLogic';
import { mergeStyle } from '@zohodesk/utils';
import style from './css/Button.module.css';
/*
Button text and children props?
use children for both cases
toLowerCase check needed?
*/

/* eslint css-modules/no-unused-class: [2, { markAsUsed: ['small','medium','large','xlarge','button_medium','button_small','primary','primaryfilled','danger','dangerfilled','plainprimary', 'plainsecondary', 'secondary', 'secondaryfilled', 'successFilled','tertiaryFilled'] }] */

export default function Button(props) {
  let {
    text,
    disabled,
    onClick,
    status,
    children,
    dataId,
    needAppearance,
    getRef,
    title,
    dataSelectorId,
    customProps,
    customStyle
  } = props;
  const finalStyle = mergeStyle(style, customStyle);
  const {
    buttonClass,
    loaderParentClass,
    loaderChildClass
  } = cssJSLogic({
    props,
    style: finalStyle
  });
  let statusLower = status.toLowerCase();
  return /*#__PURE__*/React.createElement("button", _extends({
    className: buttonClass,
    "data-id": disabled ? `${dataId}_disabled` : dataId,
    "data-test-id": disabled ? `${dataId}_disabled` : dataId,
    disabled: disabled || statusLower === 'loading',
    onClick: onClick,
    "data-title": title,
    type: "button",
    ref: getRef,
    "data-selector-id": dataSelectorId
  }, customProps), children ? children : text, statusLower !== 'none' && needAppearance && /*#__PURE__*/React.createElement("div", {
    className: finalStyle.overlay
  }, /*#__PURE__*/React.createElement("div", {
    className: loaderParentClass
  }, /*#__PURE__*/React.createElement("div", {
    className: loaderChildClass
  }))));
}
Button.defaultProps = defaultProps;
Button.propTypes = propTypes; // if (__DOCS__) {
//   Button.docs = {
//     componentGroup: 'Form Elements',
//     folderName: 'Style Guide'
//   };
// }
